@@ -10,29 +10,46 @@ import questionary
 
 
 def get_folder_choices(root_path: Path, max_depth: int) -> list:
-    """Recursively finds folders up to a max depth and prepares them for questionary."""
+    """Recursively finds folders up to a max depth and prepares them for questionary with a visual tree."""
     choices = []
-    
-    def scanner(current_path: Path, depth: int):
+
+    def scanner(current_path: Path, prefix: str, depth: int):
+        """A recursive helper to build the folder tree."""
+        # Stop scanning if the maximum depth is reached
         if depth > max_depth:
             return
             
-        relative_path = current_path.relative_to(root_path)
-        prefix = "  " * (depth - 1)
-        display_name = f"{prefix}{current_path.name}"
-        choices.append(questionary.Choice(title=display_name, value=relative_path))
-        
         try:
-            subdirs = sorted([p for p in current_path.iterdir() if p.is_dir() and p.name not in config.EXCLUDED_DIRS])
-            for subdir in subdirs:
-                scanner(subdir, depth + 1)
+            # Get a sorted list of valid subdirectories
+            subdirs = sorted([
+                p for p in current_path.iterdir()
+                if p.is_dir() and p.name not in config.EXCLUDED_DIRS
+            ])
+            
+            # Iterate through the subdirectories to build the tree display
+            for i, subdir in enumerate(subdirs):
+                is_last = (i == len(subdirs) - 1)
+                
+                # Use '└─' for the last item and '├─' for others
+                connector = "└─ " if is_last else "├─ "
+                display_name = f"{prefix}{connector}{subdir.name}"
+                
+                relative_path = subdir.relative_to(root_path)
+                choices.append(questionary.Choice(title=display_name, value=relative_path))
+                
+                # Prepare the prefix for the next level of recursion
+                # Use a blank prefix for children of the last item, and a pipe for others
+                child_prefix = prefix + ("    " if is_last else "│   ")
+                scanner(subdir, child_prefix, depth + 1)
+
         except PermissionError:
+            # Silently ignore directories that the user doesn't have permission to read
             pass
 
-    top_level_folders = sorted([p for p in root_path.iterdir() if p.is_dir() and p.name not in config.EXCLUDED_DIRS])
-    for folder in top_level_folders:
-        scanner(folder, 1)
+    # Start the recursive scan from the project's root directory
+    scanner(root_path, prefix="", depth=1)
         
+    # Add the special option to select files in the root folder itself
     root_option_name = f"root [{root_path.name}] (files in root folder only, excl. sub-folders)"
     choices.insert(0, questionary.Choice(title=root_option_name, value="ROOT_SENTINEL"))
     
@@ -56,8 +73,13 @@ def is_allowed_file(path: Path, exclude_large: bool) -> bool:
     return True
 
 
-def extract_code_from_folder(folder: Path, exclude_large: bool) -> (str, int):
-    """Extracts code from a given folder, respecting EXCLUDED_DIRS at all depths."""
+def extract_code_from_folder(folder: Path, exclude_large: bool) -> (str, int, int, int):
+    """
+    Extracts code from a given folder, respecting EXCLUDED_DIRS at all depths.
+    
+    Returns:
+        A tuple containing the content string, file count, char count, and word count.
+    """
     content = f"# Folder: {folder.relative_to(Path.cwd())}\n\n"
     extracted_files = 0
     dirs_to_visit = [folder]
@@ -80,11 +102,21 @@ def extract_code_from_folder(folder: Path, exclude_large: bool) -> (str, int):
                     content += f"\n\n"
     if extracted_files > config.FILE_COUNT_WARNING_THRESHOLD:
         logging.warning(colored(f"> Caution: Large file count in '{folder.name}' ({extracted_files} files).", "yellow"))
-    return content, extracted_files
+    
+    # ADDED: Calculate character and word counts
+    char_count = len(content)
+    word_count = len(content.split())
+    
+    return content, extracted_files, char_count, word_count
 
 
-def extract_code_from_root(root_path: Path, exclude_large: bool) -> (str, int):
-    """Extracts code only from files present in the root directory."""
+def extract_code_from_root(root_path: Path, exclude_large: bool) -> (str, int, int, int):
+    """
+    Extracts code only from files present in the root directory.
+    
+    Returns:
+        A tuple containing the content string, file count, char count, and word count.
+    """
     content = f"# Root Files: {root_path.name}\n\n"
     extracted_files = 0
     for filepath in sorted(root_path.iterdir()):
@@ -97,7 +129,12 @@ def extract_code_from_root(root_path: Path, exclude_large: bool) -> (str, int):
             extracted_files += 1
     if extracted_files > config.FILE_COUNT_WARNING_THRESHOLD:
         logging.warning(colored(f"> Caution: Large file count in root ({extracted_files} files).", "yellow"))
-    return content, extracted_files
+    
+    # ADDED: Calculate character and word counts
+    char_count = len(content)
+    word_count = len(content.split())
+
+    return content, extracted_files, char_count, word_count
 
 
 def write_to_markdown_file(content: str, metadata: dict, root_path: Path, output_dir_name: str):
@@ -116,12 +153,15 @@ def write_to_markdown_file(content: str, metadata: dict, root_path: Path, output
     filename = f"{file_base_name}_{timestamp}.md"
     full_filepath = output_dir / filename
 
+    # CHANGED: Added char_count and word_count to the YAML header
     yaml_header = f"""---
 extraction_details:
   reference: {metadata['run_ref']}
   timestamp_utc: "{metadata['run_timestamp']}"
   source_folder: "{metadata['folder_name']}"
   file_count: {metadata['file_count']}
+  char_count: {metadata['char_count']}
+  word_count: {metadata['word_count']}
 tool_details:
   name: "Codebase Extractor"
   version: "{__version__}"
